@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -38,27 +38,27 @@ def getCoordinates(header={}):
     :return:
     """
     if 'RA' in header and 'DEC' in header:
-        hasCoordFloat = True
+        hasCFloat = True
     else:
-        hasCoordFloat = False
+        hasCFloat = False
 
     if 'OBJCTRA' in header and 'OBJCTDEC' in header:
-        hasCoordDeg = True
+        hasCDeg = True
     else:
-        hasCoordDeg = False
+        hasCDeg = False
 
-    if hasCoordFloat:
+    if hasCFloat:
         ra = convertToAngle(header['RA'], isHours=True)
         dec = convertToAngle(header['DEC'], isHours=False)
-    elif hasCoordDeg:
+    elif hasCDeg:
         ra = convertRaToAngle(header['OBJCTRA'])
         dec = convertDecToAngle(header['OBJCTDEC'])
     else:
         ra = Angle(hours=0)
         dec = Angle(degrees=0)
 
-    log.debug(f'HasFloat: [{hasCoordFloat}], HasDeg: [{hasCoordDeg}]')
-    log.debug(f'Ra:[{ra}], Dec: [{dec}], Header:[{header}]')
+    log.debug(f'HasFloat: [{hasCFloat}], HasDeg: [{hasCDeg}], Header:[{header}]')
+    log.debug(f'Ra:[{ra}][{ra.hours}], Dec: [{dec}][{dec.degrees}]')
 
     return ra, dec
 
@@ -68,11 +68,14 @@ def getSQM(header={}):
     :param header:
     :return:
     """
-    sqm = max(float(header.get('SQM', 0)),
-              float(header.get('SKY-QLTY', 0)),
-              float(header.get('MPSAS', 0)),
-              )
-    return sqm
+    for key in ['SQM', 'SKY-QLTY', 'MPSAS']:
+        value = header.get(key)
+        if value is None:
+            continue
+        break
+    else:
+        return None
+    return float(value)
 
 
 def getExposure(header={}):
@@ -80,10 +83,14 @@ def getExposure(header={}):
     :param header:
     :return:
     """
-    expTime = max(float(header.get('EXPOSURE', 0)),
-                  float(header.get('EXPTIME', 0)),
-                  )
-    return expTime
+    for key in ['EXPOSURE', 'EXPTIME']:
+        value = header.get(key)
+        if value is None:
+            continue
+        break
+    else:
+        return None
+    return float(value)
 
 
 def getScale(header={}):
@@ -104,6 +111,6 @@ def getScale(header={}):
     elif hasAlternatives:
         scale = pixelSize * binning / focalLength * 206.265
     else:
-        scale = 1.0
+        scale = None
 
     return scale
