@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -18,10 +18,10 @@
 import logging
 
 # external packages
-from PyQt5.QtTest import QTest
 from PyQt5.QtCore import QTimer
 
 # local imports
+from gui.utilities.toolsQtWidget import sleepAndEvents
 from indibase.qtIndiBase import Client
 
 
@@ -125,17 +125,15 @@ class IndiClass:
         self.discoverList = None
         self.loadIndiConfig = False
         self.isINDIGO = False
-        self.showMessages = False
+        self.messages = False
 
         self.defaultConfig = {
-            'indi': {
-                'deviceName': '',
-                'deviceList': [],
-                'hostaddress': 'localhost',
-                'port': 7624,
-                'loadConfig': False,
-                'messages': False,
-            }
+            'deviceName': '',
+            'deviceList': [],
+            'hostaddress': 'localhost',
+            'port': 7624,
+            'loadConfig': False,
+            'messages': False,
         }
 
         self.timerRetry = QTimer()
@@ -274,6 +272,7 @@ class IndiClass:
         :param loadConfig:
         :return: success of reconnecting to server
         """
+        self.data.clear()
         self.loadIndiConfig = loadConfig
         self.retryCounter = 0
         self.client.startTimers()
@@ -479,7 +478,7 @@ class IndiClass:
         :param text: message received
         :return: success
         """
-        if self.showMessages:
+        if self.messages:
             if text.startswith('[WARNING]'):
                 text = self.removePrefix(text, '[WARNING]')
                 self.app.message.emit(f'INDI {device:15s} {text}', 0)
@@ -546,7 +545,7 @@ class IndiClass:
         self.client.signals.defText.connect(self.addDiscoveredDevice)
         self.client.connectServer()
         self.client.watchDevice()
-        QTest.qWait(2000)
+        sleepAndEvents(2000)
         self.client.signals.defText.disconnect(self.addDiscoveredDevice)
         self.client.disconnectServer()
         return self.discoverList
