@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -175,7 +175,8 @@ class AnalyseWindow(toolsQtWidget.MWidget):
         d = data[0]
         de = data[-1]
 
-        self.ui.filename.setText(os.path.basename(loadFilePath))
+        title = f'Analyse Model     {os.path.basename(loadFilePath)}'
+        self.setWindowTitle(title)
         self.ui.eposure.setText(f'{d.get("exposureTime", "")}')
         self.ui.solver.setText(d.get('astrometryApp', ""))
         self.ui.binning.setText(f'{d.get("binning", 0):1.0f}')
