@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -36,9 +36,12 @@ class KeypadSignals(QObject):
     textRow = pyqtSignal(object, object)
     imgChunk = pyqtSignal(object, object, object)
     keyPressed = pyqtSignal(object)
+    keyUp = pyqtSignal(object)
+    keyDown = pyqtSignal(object)
     mousePressed = pyqtSignal(object)
     mouseReleased = pyqtSignal(object)
     cursorPos = pyqtSignal(object, object)
+    clearCursor = pyqtSignal()
 
 
 class KeypadWindow(toolsQtWidget.MWidget):
@@ -58,6 +61,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         self.signals = KeypadSignals()
         self.keypad = KeyPad(self.signals)
         self.buttons = None
+        self.inputActive = False
         self.websocketMutex = QMutex()
         self.graphics = np.zeros([64, 128, 3], dtype=np.uint8)
         self.rows = [
@@ -122,11 +126,33 @@ class KeypadWindow(toolsQtWidget.MWidget):
         self.signals.textRow.disconnect(self.writeTextRow)
         self.signals.cursorPos.disconnect(self.setCursorPos)
         self.signals.imgChunk.disconnect(self.buildGraphics)
+        self.signals.clearCursor.disconnect(self.clearCursor)
         self.app.update1s.disconnect(self.startKeypad)
         self.app.update1s.disconnect(self.drawGraphics)
         self.setupButtons(connect=False)
         super().closeEvent(closeEvent)
 
+    def keyPressEvent(self, keyEvent):
+        """
+        :param keyEvent:
+        :return:
+        """
+        key = keyEvent.key()
+        if key == 16777216:
+            key = 27
+        elif key == 16777220:
+            key = 13
+        elif key == 16777249:
+            key == 16
+
+        if self.inputActive and keyEvent.type() == 6:
+            self.signals.keyPressed.emit(key)
+        elif not self.inputActive and keyEvent.type() == 6:
+            self.signals.keyDown.emit(key)
+            self.signals.keyUp.emit(key)
+
+        super().keyPressEvent(keyEvent)
+
     def showWindow(self):
         """
         :return:
@@ -141,6 +167,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         self.signals.textRow.connect(self.writeTextRow)
         self.signals.cursorPos.connect(self.setCursorPos)
         self.signals.imgChunk.connect(self.buildGraphics)
+        self.signals.clearCursor.connect(self.clearCursor)
         self.app.update1s.connect(self.startKeypad)
         self.app.update1s.connect(self.drawGraphics)
         self.setupButtons(connect=True)
@@ -225,8 +252,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         if button not in self.buttons:
             return False
 
-        keyData = self.keypad.buttonCodes[self.buttons[button]]
-        self.signals.mousePressed.emit(keyData)
+        self.signals.mousePressed.emit(self.buttons[button])
         return True
 
     def buttonReleased(self):
@@ -237,8 +263,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
         if button not in self.buttons:
             return False
 
-        keyData = self.keypad.buttonCodes[self.buttons[button]]
-        self.signals.mouseReleased.emit(keyData)
+        self.signals.mouseReleased.emit(self.buttons[button])
         return True
 
     def writeTextRow(self, row, text):
@@ -258,6 +283,7 @@ class KeypadWindow(toolsQtWidget.MWidget):
 
         if row == 4 and not text.startswith('\x00'):
             self.clearGraphics()
+
         return True
 
     def clearGraphics(self):
@@ -275,15 +301,33 @@ class KeypadWindow(toolsQtWidget.MWidget):
         for row in range(5):
             self.writeTextRow(row, '')
         self.clearGraphics()
+        self.clearCursor()
+        self.inputActive = False
         return True
 
-    def setCursorPos(self, col, row):
+    def clearCursor(self):
         """
-        :param col:
-        :param row:
         :return:
         """
-        self.rows[row].setCursorPosition(col)
+        self.inputActive = False
+        self.ui.cursor.setVisible(False)
+        return True
+
+    def setCursorPos(self, row, col):
+        """
+        :param row:
+        :param col:
+        :return:
+        """
+        self.inputActive = True
+        x = self.rows[row].x()
+        y = self.rows[row].y()
+        height = self.rows[row].height()
+
+        self.ui.cursor.setStyleSheet(f'background-color: {self.M_BACK};')
+        self.ui.cursor.setStyleSheet(f'color: {self.M_BLUE};')
+        self.ui.cursor.setVisible(True)
+        self.ui.cursor.move(x + 16 * col, y + height)
         return True
 
     def drawGraphics(self):
