@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -36,7 +36,7 @@ class SatelliteWindowSignals(QObject):
     """
     """
     __all__ = ['SatelliteWindowSignals']
-    show = pyqtSignal(object, object, object, object)
+    show = pyqtSignal(object, object, object, object, object)
     update = pyqtSignal(object, object)
 
 
@@ -68,7 +68,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         self.satHorizonMat = self.embedMatplot(self.ui.satHorizon)
         self.satEarthMat = self.embedMatplot(self.ui.satEarth)
 
-        self.colors = [self.M_RED1, self.M_YELLOW1, self.M_GREEN1]
+        self.colors = [self.M_RED, self.M_YELLOW, self.M_GREEN]
         stream = QFile(':/data/worldmap.dat')
         stream.open(QFile.ReadOnly)
         pickleData = stream.readAll()
@@ -140,7 +140,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         :return:
         """
         self.setStyleSheet(self.mw4Style)
-        self.colors = [self.M_RED1, self.M_YELLOW1, self.M_GREEN1]
+        self.colors = [self.M_RED, self.M_YELLOW, self.M_GREEN]
         self.drawSatellite()
         return True
 
@@ -212,7 +212,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
             return False
 
         observe = self.satellite.at(now)
-        subpoint = wgs84.subpoint(observe)
+        subpoint = wgs84.subpoint_of(observe)
         difference = self.satellite - location
 
         self.ui.satLatitude.setText(f'{subpoint.latitude.degrees:3.2f}')
@@ -444,7 +444,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
             axe.figure.canvas.draw()
             return False
 
-        subpoints = wgs84.subpoint(observe)
+        subpoints = wgs84.subpoint_of(observe)
         lat = subpoints.latitude.radians
         lon = subpoints.longitude.radians
         elev = subpoints.elevation.m / 1000 + self.EARTH_RADIUS * 1.1
@@ -515,7 +515,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         axe.plot(lon, lat, marker='.', markersize=5, color=self.M_YELLOW)
 
         ts = obsSite.ts
-        subpoint = wgs84.subpoint(self.satellite.at(ts.now()))
+        subpoint = wgs84.subpoint_of(self.satellite.at(ts.now()))
         lat = subpoint.latitude.degrees
         lon = subpoint.longitude.degrees
         self.plotSatPosEarth, = axe.plot(lon, lat,
@@ -538,7 +538,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
 
             vector = np.arange(rise, flip, step)
             vecT = ts.tt_jd(vector)
-            subpoints = wgs84.subpoint(self.satellite.at(vecT))
+            subpoints = wgs84.subpoint_of(self.satellite.at(vecT))
             lat = subpoints.latitude.degrees
             lon = subpoints.longitude.degrees
             for slc in self.unlinkWrap(lon):
@@ -546,7 +546,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
 
             vector = np.arange(flip, settle, step)
             vecT = ts.tt_jd(vector)
-            subpoints = wgs84.subpoint(self.satellite.at(vecT))
+            subpoints = wgs84.subpoint_of(self.satellite.at(vecT))
             lat = subpoints.latitude.degrees
             lon = subpoints.longitude.degrees
             for slc in self.unlinkWrap(lon):
@@ -558,7 +558,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         step = 0.001 * (settle - rise)
         vector = np.arange(rise - 0.15, settle, step)
         vecT = ts.tt_jd(vector)
-        subpoints = wgs84.subpoint(self.satellite.at(vecT))
+        subpoints = wgs84.subpoint_of(self.satellite.at(vecT))
         lat = subpoints.latitude.degrees
         lon = subpoints.longitude.degrees
         for slc in self.unlinkWrap(lon):
@@ -678,7 +678,7 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         return True
 
     def drawSatellite(self, satellite=None, satOrbits=None, altitude=[],
-                      azimuth=[]):
+                      azimuth=[], name=''):
         """
         drawSatellite draws 4 different views of the actual satellite
         situation: two sphere views, a horizon view and an earth view.
@@ -689,11 +689,13 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         :param satOrbits:
         :param altitude:
         :param azimuth:
+        :param name:
         :return: True for test purpose
         """
         if self.closing:
             return False
 
+        self.setWindowTitle(f'Satellite {name}')
         if satellite is None or satOrbits is None:
             self.drawEarth()
             self.drawHorizonView()
