@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -45,7 +45,7 @@ class Relay(object):
 
         for status, button in zip(self.app.relay.status, self.relayButtons):
             if status:
-                self.changeStyleDynamic(button, 'running', 'true')
+                self.changeStyleDynamic(button, 'running', True)
             else:
-                self.changeStyleDynamic(button, 'running', 'false')
+                self.changeStyleDynamic(button, 'running', False)
         return True
