@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -264,8 +264,13 @@ class SatTrack(object):
             if counter > 2:
                 break
 
-        if not self.satOrbits:
+        if not self.satOrbits and np.all(events == 1) and len(events) > 0:
+            self.satOrbits.append({'rise': times[0]})
+            self.satOrbits[0]['culminate'] = times[0] + 0.5
+            self.satOrbits[0]['settle'] = times[0] + 1.0
+        elif not self.satOrbits:
             return False
+
         if 'settle' not in self.satOrbits[-1]:
             del self.satOrbits[counter]
             return False
@@ -359,11 +364,12 @@ class SatTrack(object):
         winObj = self.app.uiWindows['showSatelliteW']
         if not winObj['classObj']:
             return False
-
+        name = self.satellite.name
         winObj['classObj'].signals.show.emit(self.satellite,
                                              self.satOrbits,
                                              alt,
-                                             az)
+                                             az,
+                                             name)
         return True
 
     def clearTrackingParameters(self):
@@ -377,7 +383,7 @@ class SatTrack(object):
         self.ui.stopSatelliteTracking.setEnabled(False)
         self.ui.startSatelliteTracking.setEnabled(False)
         self.ui.startSatelliteTracking.setText('Start satellite tracking')
-        self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', 'false')
+        self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', False)
         return True
 
     def updatePasses(self):
@@ -524,7 +530,7 @@ class SatTrack(object):
         if self.satellite is None:
             self.ui.startSatelliteTracking.setEnabled(False)
             self.ui.stopSatelliteTracking.setEnabled(False)
-            self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', 'false')
+            self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', False)
             return False
 
         now = self.app.mount.obsSite.ts.now()
@@ -630,21 +636,24 @@ class SatTrack(object):
         """
         :return:
         """
+        useInternal = self.ui.useInternalSatCalc.isChecked()
+        isMount = self.app.deviceStat['mount']
         start, end = self.selectStartEnd()
+
         if not start or not end:
             return False
 
-        useInternal = self.ui.useInternalSatCalc.isChecked()
-        if useInternal:
+        if isMount and useInternal:
             alt, az = self.calcTrajectoryData(start, end)
             start, end, alt, az = self.filterHorizon(start, end, alt, az)
         else:
             alt = []
             az = []
-        self.sendSatelliteData(alt=alt, az=az)
-        if self.app.deviceStat['mount'] and not useInternal:
+
+        if isMount and not useInternal:
             self.app.mount.calcTLE(start)
 
+        self.sendSatelliteData(alt=alt, az=az)
         return True
 
     def startProg(self):
@@ -755,7 +764,7 @@ class SatTrack(object):
             return False
 
         self.ui.startSatelliteTracking.setText('Start satellite tracking')
-        self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', 'false')
+        self.changeStyleDynamic(self.ui.startSatelliteTracking, 'running', False)
         self.app.message.emit('Stopped tracking', 0)
         return suc
 
