@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -22,11 +22,14 @@ import platform
 # external packages
 
 # local imports
+from base.transform import JNowToJ2000
 from base.driverDataClass import Signals
 from logic.camera.cameraIndi import CameraIndi
 from logic.camera.cameraAlpaca import CameraAlpaca
 if platform.system() == 'Windows':
     from logic.camera.cameraAscom import CameraAscom
+    from logic.camera.cameraSGPro import CameraSGPro
+    from logic.camera.cameraNINA import CameraNINA
 
 
 class Camera:
@@ -50,10 +53,14 @@ class Camera:
         }
 
         if platform.system() == 'Windows':
+            self.run['nina'] = CameraNINA(self.app, self.signals, self.data)
+            self.run['sgpro'] = CameraSGPro(self.app, self.signals, self.data)
             self.run['ascom'] = CameraAscom(self.app, self.signals, self.data)
 
         for fw in self.run:
-            self.defaultConfig['frameworks'].update(self.run[fw].defaultConfig)
+            self.defaultConfig['frameworks'].update({fw: self.run[fw].defaultConfig})
+
+        self.signals.deviceDisconnected.connect(self.abort)
 
     def startCommunication(self, loadConfig=False):
         """
@@ -110,15 +117,10 @@ class Camera:
         :param subFrame: percentage 0-100 of
         :return: success
         """
-        if 'CCD_INFO.CCD_MAX_X' not in self.data:
-            return False
-        if 'CCD_INFO.CCD_MAX_Y' not in self.data:
-            return False
+        maxX = self.data.get('CCD_INFO.CCD_MAX_X', 0)
+        maxY = self.data.get('CCD_INFO.CCD_MAX_Y', 0)
 
-        maxX = self.data['CCD_INFO.CCD_MAX_X']
-        maxY = self.data['CCD_INFO.CCD_MAX_Y']
-
-        if subFrame < 10 or subFrame > 100:
+        if subFrame < 10 or subFrame > 100 or maxX == 0 or maxY == 0:
             width = maxX
             height = maxY
             posX = 0
@@ -162,22 +164,26 @@ class Camera:
             return False
         if not imagePath:
             return False
-        if not self.canSubFrame(subFrame=subFrame):
-            self.log.warning('Camera does not support subframe')
-            return False
-        if not self.canBinning(binning=binning):
-            self.log.info('Camera does not support binning, set to 1')
+        raJNow = self.app.mount.obsSite.raJNow
+        decJNow = self.app.mount.obsSite.decJNow
+        timeJD = self.app.mount.obsSite.timeJD
+        if raJNow is not None and decJNow is not None and timeJD is not None:
+            raJ2000, decJ2000 = JNowToJ2000(raJNow, decJNow, timeJD)
+        else:
+            raJ2000 = None
+            decJ2000 = None
+        if subFrame != 100 and not self.canSubFrame(subFrame=subFrame):
+            subFrame = 100
+        if binning != 1 and not self.canBinning(binning=binning):
             binning = 1
-
         result = self.calcSubFrame(subFrame=subFrame)
-        if not result:
-            return False
 
         posX, posY, width, height = result
 
-        text = f'Image bin:{binning}, posX:{posX}, posY:{posY}'
-        text += f', width:{width}, height:{height}, fast:{fastReadout}'
-        self.log.debug(text)
+        t = f'Image bin:{binning}, posX:{posX}, posY:{posY}'
+        t += f', width:{width}, height:{height}, fast:{fastReadout}'
+        self.log.debug(t)
+        self.signals.message.emit(f'exposing')
         suc = self.run[self.framework].expose(imagePath=imagePath,
                                               expTime=expTime,
                                               binning=binning,
@@ -186,7 +192,9 @@ class Camera:
                                               posY=posY,
                                               width=width,
                                               height=height,
-                                              focalLength=focalLength)
+                                              focalLength=focalLength,
+                                              ra=raJ2000,
+                                              dec=decJ2000)
         return suc
 
     def abort(self):
